All Classes and Interfaces

Class
Description
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
Deprecated.
Since 7.19.0.
Deprecated.
Since 7.19.0.
Deprecated.
Since 7.19.0.
Deprecated.
Since 7.19.0.
This rule detects an abnormally long parameter list.
Deprecated.
Since 7.19.0.
Methods required to be considered as an executable piece of code.
Internal API.
 
 
 
 
 
 
Deprecated.
Since 7.19.0.
Deprecated.
Since 7.19.0.
NPath complexity is a measurement of the acyclic execution paths through a function.
 
All nodes that represent an Oracle object.
Note: This class has been called PLSQLTokenizer in PMD 6
Implementation of LanguageVersionHandler for the PLSQL AST.
Created by christoferdutz on 20.09.14.
Built-in PL/SQL metrics.
 
 
 
Deprecated.
Since 7.3.0.
Token kinds (JavaccToken.kind) for this language.
 
Base implementation of PlsqlVisitor.
Visitor for scope creation.
 
 
 
 
Keeps track of the types encountered in a ASTinput
 
 
 
 
 
 
TODO should Resolver provide a canResolve() and a resolve()?