Class PLSQLParserImpl

java.lang.Object
net.sourceforge.pmd.lang.plsql.ast.PLSQLParserImpl

@Deprecated @Generated("org.javacc.javacc") public class PLSQLParserImpl extends Object
Deprecated.
Since 7.3.0. PLSQLParserImpl should have been package private because this is an implementation class that should not be used directly.