Class ExcessiveMethodLengthRule

All Implemented Interfaces:
AstVisitor<Object,Object>, PlsqlVisitor<Object,Object>, Rule, PropertySource

@Deprecated public class ExcessiveMethodLengthRule extends AbstractPLSQLRule
Deprecated.
Since 7.19.0. Use the rule NcssCountRule instead.
This rule detects when a method exceeds a certain threshold. i.e. if a method has more than x lines of code.

Equivalent XPath: //(MethodDeclaration|ProgramUnit|TriggerTimingPointSection|TriggerUnit|TypeMethod)[@EndLine - @BeginLine > 100]

  • Constructor Details

    • ExcessiveMethodLengthRule

      public ExcessiveMethodLengthRule()
      Deprecated.
  • Method Details